@@ -27,6 +27,8 @@ logger = logging.getLogger(__name__)
 # download the content (i.e TemplateURL in cloudformation).
 PARAMFILE_DISABLED = set([
     'apigateway.put-integration.uri',
+    'appstream2.create-stack.redirect-url',
+    'appstream2.update-stack.redirect-url',
     'cloudformation.create-stack.template-url',
     'cloudformation.update-stack.template-url',
     'cloudformation.create-stack-set.template-url',
@@ -73,6 +75,16 @@ PARAMFILE_DISABLED = set([
     'rds.copy-db-snapshot.pre-signed-url',
     'rds.create-db-instance-read-replica.pre-signed-url',
 
+    'serverlessrepo.create-application.home-page-url',
+    'serverlessrepo.create-application.license-url',
+    'serverlessrepo.create-application.readme-url',
+    'serverlessrepo.create-application.source-code-url',
+    'serverlessrepo.create-application.template-url',
+    'serverlessrepo.create-application-version.source-code-url',
+    'serverlessrepo.create-application-version.template-url',
+    'serverlessrepo.update-application.home-page-url',
+    'serverlessrepo.update-application.readme-url',
+
     'sqs.add-permission.queue-url',
     'sqs.change-message-visibility.queue-url',
     'sqs.change-message-visibility-batch.queue-url',
@@ -100,6 +112,8 @@ PARAMFILE_DISABLED = set([
 
     'iot.create-job.document-source',
     'translate.translate-text.text',
+
+    'workdocs.create-notification-subscription.notification-endpoint',
 ])
 
 
